
<p align="center">
  <img src="https://raw.githubusercontent.com/PySimpleGUI/PySimpleGUI/master/images/for_readme/Logo%20with%20text%20for%20GitHub%20Top.png" alt="Python GUIs for Humans">
  <h2 align="center">Figlet Creation</h2>
</p>

Create Figlets easily using this application created using PySimpleGUI.

## Installation

### Old-school Straight Pip

pip install psg-figlet

### pip via `python -m pip` the python recommended way

#### If `python` is your command

python -m pip install psg-figlet

#### If `python3` is your command

python3 -m pip install psg-figlet

## Usage

To run the program and create your own Figlets type from your command prompt:

psg-figlet




## About - What is a Figlet?

A Figlet is a text based way to add large block text to your code or chats.  There are a variety of "Fonts" available that you'll find listed along the left side of the screen.

![image](https://user-images.githubusercontent.com/46163555/136379651-58f474d7-fbfa-423f-a5da-162d6936d104.png)

## To use in your code

The easiest way to is make a multiline string in your code using triple quotes:

```python

'''
This is a multiline string
Line 2
'''
```


You can simply paste your Figlet into one of these multiline comments.  They work well at breaking up your code into chunks

```python

'''
                    oo          
                                
88d8b.d8b. .d8888b. dP 88d888b. 
88'`88'`88 88'  `88 88 88'  `88 
88  88  88 88.  .88 88 88    88 
dP  dP  dP `88888P8 dP dP    dP
'''

def main():
    x = 20

```

## License

Licensed under an LGPL3 License

## Designed and Written By

Mike from PySimpleGUI.org

## Contributing

Like the PySimpleGUI project, this project is currently licensed under an open-source license, the project itself is structured like a proprietary product. Pull Requests are not accepted.

## Copyright

Copyright 2021 PySimpleGUI
